System.register(['./generated-main.js'], (function (exports) {
	'use strict';
	return {
		setters: [function (module) {
			exports('unused', module.u);
		}],
		execute: (function () {



		})
	};
}));
